==> hs-vector-space-0.8.2.tbz: lib/ghc-7.4.1/cabal/vector-space-0.8.2/register.sh <==
#!/bin/sh
echo 'name: vector-space
version: 0.8.2
id: vector-space-0.8.2-b4cfe01eaff6b02ab2c768dc714ebb8c

license: BSD3
copyright: (c) 2008-2012 by Conal Elliott
maintainer: conal@conal.net
stability: experimental
homepage: http://haskell.org/haskellwiki/vector-space
package-url: http://code.haskell.org/vector-space
synopsis: Vector & affine spaces, linear maps, and derivatives
description: /vector-space/ provides classes and generic operations for vector
             spaces and affine spaces.  It also defines a type of infinite towers
             of generalized derivatives.  A generalized derivative is a linear
             transformation rather than one of the common concrete representations
             (scalars, vectors, matrices, ...).
             .
             /Warning/: this package depends on type families working fairly well,
             and requires ghc version at least 6.9.
             .
             Project wiki page: <http://haskell.org/haskellwiki/vector-space>
             .
             &#169; 2008-2012 by Conal Elliott; BSD3 license.
category: math
author: Conal Elliott
exposed: True
exposed-modules: Data.AdditiveGroup Data.VectorSpace Data.Basis
                 Data.LinearMap Data.Maclaurin Data.Derivative Data.Cross
                 Data.AffineSpace
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/vector-space-0.8.2
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/vector-space-0.8.2
              /usr/local/lib
hs-libraries: HSvector-space-0.8.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: Boolean-0.0.1-b1d168900d88171794c928b57fea6d8e
         MemoTrie-0.5-c726f7961d37f01f2cab3ec3829f4587
         NumInstances-1.0-a7781b40bd2da97d16ea22bc5afe66db
         base-4.5.0.0-1a022b3476300ed3e5bfdd46dd7221d0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/vector-space-0.8.2/html/vector-space.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/vector-space-0.8.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-vector-space-0.8.6_2.tbz: lib/ghc-7.4.2/cabal/vector-space-0.8.6/register.sh <==
#!/bin/sh
echo 'name: vector-space
version: 0.8.6
id: vector-space-0.8.6-fdb3f237a0740e93faac710667c00238

license: BSD3
copyright: (c) 2008-2012 by Conal Elliott
maintainer: conal@conal.net
stability: experimental
homepage:
package-url:
synopsis: Vector & affine spaces, linear maps, and derivatives
description: /vector-space/ provides classes and generic operations for vector
             spaces and affine spaces.  It also defines a type of infinite towers
             of generalized derivatives.  A generalized derivative is a linear
             transformation rather than one of the common concrete representations
             (scalars, vectors, matrices, ...).
             .
             /Warning/: this package depends on type families working fairly well,
             requiring GHC version at least 6.9.
             .
             Project wiki page: <http://haskell.org/haskellwiki/vector-space>
             .
             &#169; 2008-2012 by Conal Elliott; BSD3 license.
category: math
author: Conal Elliott
exposed: True
exposed-modules: Data.AdditiveGroup Data.VectorSpace Data.Basis
                 Data.LinearMap Data.Maclaurin Data.Derivative Data.Cross
                 Data.AffineSpace
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/vector-space-0.8.6
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/vector-space-0.8.6
              /usr/local/lib
hs-libraries: HSvector-space-0.8.6
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: Boolean-0.2-570d759ed9650eb5b2ed34796debc107
         MemoTrie-0.6.1-56659213ce427de8ca9101f68a968794
         NumInstances-1.2-8aaed396bd9fbe6769cf3f28f5794750
         base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/vector-space-0.8.6/html/vector-space.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/vector-space-0.8.6/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
